pub struct Diary {
pub profile: StudentProfile,
/* private fields */
}Fields
profile: StudentProfileImplementations
Sourceimpl Diary
impl Diary
pub async fn new<S: Into<String>>(token: S) -> Result<Self>
pub async fn session(&self) -> Result<StudentSession>
pub async fn academic_years(&self) -> Result<Vec<AcademicYear>>
pub async fn schedule(&self, date: DateTime<Utc>) -> Result<Schedule>
pub async fn final_marks(&self, year: &AcademicYear) -> Result<Vec<FinalMark>>
pub async fn final_marks_id(&self, year_id: u16) -> Result<Vec<FinalMark>>
Sourcepub async fn lesson_plan(&self, lesson: &LessonInstance) -> Result<LessonPlan>
pub async fn lesson_plan(&self, lesson: &LessonInstance) -> Result<LessonPlan>
Gets module lesson plan for the provided lesson.
Returns Err when the lesson lacks a scheduled plan (at least according to API)
Sourcepub async fn lesson_plan_wid(&self, plan_id: u64) -> Result<LessonPlan>
pub async fn lesson_plan_wid(&self, plan_id: u64) -> Result<LessonPlan>
Gets module lesson plan with the provided lesson plan ID
pub async fn homework( &self, from: DateTime<Utc>, to: DateTime<Utc>, ) -> Result<Vec<StudentHomework>>
pub async fn download_attachment( &self, path: PathBuf, attachment: &HomeworkAttachment, ) -> Result<()>
Sourcepub async fn progress(&self) -> Result<Vec<GlobalAverageGrade>>
pub async fn progress(&self) -> Result<Vec<GlobalAverageGrade>>
Gets the progress report for the current student
pub async fn visits( &self, from: DateTime<Utc>, to: DateTime<Utc>, ) -> Result<Vec<StudentAttendance>>